bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.lower_bound_contribution
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.lower_bound_contribution